@@ -5,5 +5,5 @@ function (documents, topics, model, alpha, eta, num.iterations = 100,
     doc_sums_count <- slda.predict.docsums(documents, topics, 
         alpha, eta, num.iterations, average.iterations, trace)
     props <- t(doc_sums_count)/colSums(doc_sums_count)
-    props %*% coef(model)
+     props %*% matrix(coef(model),nrow=ncol(props), byrow=T)
 }
